#
# Copyright (C) 2020-2021 MicroSys Electronics GmbH
#
inherit u_boot_addons

FILESEXTRAPATHS_prepend := "${THISDIR}/${BPN}:"

UBOOT_BRANCH = "integration"
SRCREV= "e2eba0cd581b91181aaba0302b9918e0effe4ae2"

S = "${WORKDIR}/git"
B = "${WORKDIR}/build"

PV_append = "+microsys"
LOCALVERSION = "+microsys"


INSANE_SKIP_${PN} = "arch"
INHIBIT_PACKAGE_STRIP = "1"
INHIBIT_PACKAGE_DEBUG_SPLIT = "1"
INHIBIT_SYSROOT_STRIP = "1"
PATCHTOOL = "git"

python do_patch_prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}

do_configure_append() {
	if [ ${MACHINE} = "mpxls1088crx05" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*mc\.itb,filename \= \"${DEPLOY_DIR_IMAGE}/mc_app/mc.itb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpc.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpc-crx05.0x12-0x0D.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpl.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpl-eth-crx05.0x12_0x0D.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
	fi
	if [ ${MACHINE} = "mpxls1088crx06" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*mc\.itb,filename \= \"${DEPLOY_DIR_IMAGE}/mc_app/mc.itb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpc.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpc-crx06-2tsn.0x19-0x0C.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpl.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpl-eth-crx06-2tsn.0x19_0x0C.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
	fi
	if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*mc\.itb,filename \= \"${DEPLOY_DIR_IMAGE}/mc_app/mc.itb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpc.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpc-crx06-2qsgmii.0x1D-0x0C.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
		sed -i -e "s,filename.*dpl.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpl-eth-crx06-2qsgmii.0x1D_0x0C.dtb," ${S}/arch/arm/dts/qspi_firmware_mpxls1088.dts
	fi

    # We are doing the same for every mpxls1043 machine
    if [ "${MACHINE}" = "mpxls1043ac1000msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1000pciecrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600pciecrx05" ] ; then
        sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1043.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1043.dts
        sed -i -e "s,filename.*fman_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/fsl_fman_ucode_ls1043_r1.1_106_4_18.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1043.dts
        sed -i -e "s,filename.*qe_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/boot/iram_Type_A_LS1021a_r1.0.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1043.dts

		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_nand.pbl," ${S}/arch/arm/dts/nand_firmware_mpxls1043.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/nand_firmware_mpxls1043.dts
		sed -i -e "s,filename.*fman_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/fsl_fman_ucode_ls1043_r1.1_106_4_18.bin," ${S}/arch/arm/dts/nand_firmware_mpxls1043.dts
		sed -i -e "s,filename.*qe_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/boot/iram_Type_A_LS1021a_r1.0.bin," ${S}/arch/arm/dts/nand_firmware_mpxls1043.dts
	fi
	if [ ${MACHINE} = "mpxls1046ram2gbcrx05" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fman_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/fsl_fman_ucode_ls1046_r1.0_106_4_18.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
	fi
	if [ ${MACHINE} = "mpxls1046ram4gbcrx05" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fman_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/fsl_fman_ucode_ls1046_r1.0_106_4_18.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
	fi
	if [ ${MACHINE} = "mpxls1046crx06" ]; then
		sed -i -e "s,filename.*bl2_qspi\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_qspi.pbl," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fip.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
		sed -i -e "s,filename.*fman_ucode.*\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/fsl_fman_ucode_ls1046_r1.0_106_4_18.bin," ${S}/arch/arm/dts/qspi_firmware_mpxls1046.dts
	fi
	if [ ${MACHINE} = "mpxlx2160acrx08" ]; then
		sed -i -e "s,filename.*bl2_flexspi_nor\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_flexspi_nor.pbl," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*fip\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*fip_ddr_all\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/ddr-phy/fip_ddr_all.bin," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*mc.*\.itb,filename \= \"${DEPLOY_DIR_IMAGE}/mc_app/mc.itb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*dpc.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpc-usxgmii.crx08.dtb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*dpl.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpl-eth.19.dtb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
	fi
	if [ ${MACHINE} = "mpxlx2160acrx08ai" ]; then
		sed -i -e "s,filename.*bl2_flexspi_nor\.pbl,filename \= \"${DEPLOY_DIR_IMAGE}/atf/bl2_flexspi_nor.pbl," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*fip\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/atf/fip_uboot.bin," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*fip_ddr_all\.bin,filename \= \"${DEPLOY_DIR_IMAGE}/ddr-phy/fip_ddr_all.bin," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*mc.*\.itb,filename \= \"${DEPLOY_DIR_IMAGE}/mc_app/mc.itb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*dpc.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpc-usxgmii.crx08.dtb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
		sed -i -e "s,filename.*dpl.*dtb,filename \= \"${DEPLOY_DIR_IMAGE}/dpl-eth.19.dtb," ${S}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dts
	fi
}

do_compile_append_qoriq() {
    if [ ${MACHINE} = "mpxls1088crx05" ]; then
		cd ${B}
        cp ${S}/board/microsys/mpxls1088/dpl-eth-crx05.0x12_0x0D.dts ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        cp ${S}/board/microsys/mpxls1088/dpc-crx05.0x12-0x0D.dts  ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx05.0x12-0x0D.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx05.0x12-0x0D.dtb
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx05.0x12_0x0D.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx05.0x12_0x0D.dtb
     fi
    if [ ${MACHINE} = "mpxls1088crx06" ]; then
		cd ${B}
        cp ${S}/board/microsys/mpxls1088/dpl-eth-crx06-2tsn.0x19_0x0C.dts ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        cp ${S}/board/microsys/mpxls1088/dpc-crx06-2tsn.0x19-0x0C.dts  ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2tsn.0x19-0x0C.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2tsn.0x19-0x0C.dtb
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2tsn.0x19_0x0C.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2tsn.0x19_0x0C.dtb
     fi
    if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
		cd ${B}
        cp ${S}/board/microsys/mpxls1088/dpl-eth-crx06-2qsgmii.0x1D_0x0C.dts ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        cp ${S}/board/microsys/mpxls1088/dpc-crx06-2qsgmii.0x1D-0x0C.dts  ${UBOOT_MACHINE}/board/microsys/mpxls1088/
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2qsgmii.0x1D-0x0C.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2qsgmii.0x1D-0x0C.dtb
        dtc ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2qsgmii.0x1D_0x0C.dts -o ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2qsgmii.0x1D_0x0C.dtb
     fi
}

do_install_append() {
if [ ${MACHINE} != "mpxls1028crx07" ]; then
	install -d ${D}${bindir_crossscripts}/
	install -m 0755 ${S}/tools/binman/binman ${D}${bindir_crossscripts}/binman
	install -d ${D}${bindir_crossscripts}/
    install -m 0755 ${S}/tools/binman/binman ${D}${bindir_crossscripts}/binman
	install -d ${D}${libdir}/
	install -d ${D}${libdir}/binman/
	install -d ${D}${libdir}/binman/etype/
	install -d ${D}${libdir}/patman/
	install -d ${D}${libdir}/dtoc/
	install -m 0644 ${S}/tools/binman/*.py ${D}${libdir}/binman/

	install -m 0644 ${S}/tools/binman/etype/*.py ${D}${libdir}/binman/etype/
    install -m 0644 ${S}/tools/patman/*.py ${D}${libdir}/patman/
    install -m 0644 ${S}/tools/patman/patman ${D}${libdir}/patman/patman
    install -m 0644 ${S}/tools/dtoc/*.py ${D}${libdir}/dtoc/


	cd ${B}
	install -m 0644 ${UBOOT_MACHINE}/scripts/dtc/pylibfdt/_libfdt*.so ${D}${libdir}/
	install -m 0644 ${UBOOT_MACHINE}/scripts/dtc/pylibfdt/libfdt.i ${D}${libdir}/libfdt.i
	install -m 0644 ${UBOOT_MACHINE}/scripts/dtc/pylibfdt/libfdt.py ${D}${libdir}/libfdt.py
fi
}
SYSROOT_DIRS += "${bindir_crossscripts} ${libdir}"


do_deploy_append() {
cd ${B}
install -d ${DEPLOYDIR}
install -m 0644 ${S}/localversion-microsys ${DEPLOYDIR}/

	if [ ${MACHINE} = "mpxls1046ram2gbcrx05" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1046.dtb ${DEPLOYDIR}/
    fi
	if [ ${MACHINE} = "mpxls1046ram4gbcrx05" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1046.dtb ${DEPLOYDIR}/
    fi

    if [ ${MACHINE} = "mpxls1046crx06" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1046.dtb ${DEPLOYDIR}/
    fi

    # We are doing the same for every mpxls1043 machine
    if [ "${MACHINE}" = "mpxls1043ac1000msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1000pciecrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600pciecrx05" ] ; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/nand_firmware_mpxls1043.dtb ${DEPLOYDIR}/
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1043.dtb ${DEPLOYDIR}/
    fi
    if [ ${MACHINE} = "mpxls1088crx05" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1088.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx05.0x12_0x0D.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx05.0x12-0x0D.dtb ${DEPLOYDIR}/
    fi
    if [ ${MACHINE} = "mpxls1088crx06" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1088.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2tsn.0x19_0x0C.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2tsn.0x19-0x0C.dtb ${DEPLOYDIR}/
    fi
    if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
		install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/qspi_firmware_mpxls1088.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpl-eth-crx06-2qsgmii.0x1D_0x0C.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/board/microsys/mpxls1088/dpc-crx06-2qsgmii.0x1D-0x0C.dtb ${DEPLOYDIR}/
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08" ]; then
	install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/arch/arm/dts/dpl-eth.19.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/arch/arm/dts/dpc-usxgmii.crx08.dtb ${DEPLOYDIR}/
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08ai" ]; then
	install -m 0644 ${UBOOT_MACHINE}/arch/arm/dts/xspi_firmware_mpxlx2160_crx08.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/arch/arm/dts/dpl-eth.19.dtb ${DEPLOYDIR}/
        install ${UBOOT_MACHINE}/arch/arm/dts/dpc-usxgmii.crx08.dtb ${DEPLOYDIR}/
    fi
}


PACKAGES += "${PN}-binman"
FILES_SOLIBDEV = ""
FILES_${PN} += "/usr/bin/crossscripts/binman ${libdir}/binman/ ${libdir}/patman/ ${libdir}/*.so ${libdir}/*.i ${libdir}/*.py ${libdir}/binman/etype/ ${libdir}/dtoc/"
FILES_${PN}-binman += "/usr/bin/crosscripts/binman ${libdir}/binman/ ${libdir}/patman ${libdir}/*.so ${libdir}/*.i ${libdir}/*.py"
PROVIDES += "u-boot-qoriq-binman"
COMPATIBLE_MACHINE = "(qoriq)"

SRC_URI += "file://0001-mpxls1046-Added-PCIe-EP-support.patch;name=patch0001"
SRC_URI += "file://0002-generic_10g-added-startup-with-autoneg.patch;name=patch0002"
SRC_URI += "file://0003-EEPROM-Copy-Serial-number-to-U-Boot-Environment.patch;name=patch0003"
SRC_URI += "file://0004-sys_eeprom-replaced-EEPROM-access-routines.patch;name=patch0004"
SRC_URI += "file://0005-net-fm-MDIO-clocking-fix.patch;name=patch0005"
SRC_URI += "file://0006-drivers-rtc-added-PCF85063-PCF85263-RV8564.patch;name=patch0006"
SRC_URI += "file://0007-env-eeprom-fixed-support-for-environment-in-I2C-EEPR.patch;name=patch0007"
SRC_URI += "file://0008-phy-marvell-update-to-latest-version.patch;name=patch0008"
SRC_URI += "file://0009-gpio-fxl6408-added-driver.patch;name=patch0009"
SRC_URI += "file://0010-Added-command-to-Update-Firmware-Images-to-NAND-QSPI.patch;name=patch0010"
SRC_URI += "file://0011-qspi-n25128a-enabled-subsector-access.patch;name=patch0011"
SRC_URI += "file://0012-SPI-flash-Fixed-Support-for-ST-Micron-Quad-SPI.patch;name=patch0012"
SRC_URI += "file://0013-net-fsl_netc-connect-and-configure-PHY.patch;name=patch0013"
SRC_URI += "file://0014-envtools-Add-sysroot-path.patch;name=patch0014"
SRC_URI += "file://0015-env-support-environment-in-EEPROM.patch;name=patch0015"
SRC_URI += "file://0016-gpio-added-driver-for-QorIQ-GPIO-controller.patch;name=patch0016"
SRC_URI += "file://0017-cmd-gpio-fixed-setting-GPIO.patch;name=patch0017"
SRC_URI += "file://0018-drivers-misc-added-driver-for-TUSB8041.patch;name=patch0018"
SRC_URI += "file://0019-mpx-added-device-trees.patch;name=patch0019"
SRC_URI += "file://0020-Added-device-tree-nand-qspi-xspi-firmware-images.patch;name=patch0020"
SRC_URI += "file://0021-mpxlx2160-Added-dpc-and-dpl-device-trees-for-managem.patch;name=patch0021"
SRC_URI += "file://0022-microsys-crx06-added-support.patch;name=patch0022"
SRC_URI += "file://0023-drivers-phy-ti-fixed-handling-of-mirroring.patch;name=patch0023"
SRC_URI += "file://0024-comels1046a-phy-changes-for-RGMII-on-COMe-LS1046A.patch;name=patch0024"
SRC_URI += "file://0025-drivers-mmc-Disabled-SD-High-Speed-Capability-for-DM.patch;name=patch0025"
SRC_URI += "file://0026-spi-nxp_fspi-Default-MMU-Setup-for-FLEXSPI-memory-co.patch;name=patch0026"
SRC_URI += "file://0027-cmd-eeprom-disabled-command-eeprom.patch;name=patch0027"
SRC_URI += "file://0028-include-nand.h-added-config-guard.patch;name=patch0028"
SRC_URI += "file://0029-drivers-mmc-added-OF-properties-with-no-HS.patch;name=patch0029"
SRC_URI += "file://0030-mpx-come-added-configuration.patch;name=patch0030"
SRC_URI += "file://0031-microsys-added-common-directory.patch;name=patch0031"
SRC_URI += "file://0032-microsys-added-common-include.patch;name=patch0032"
SRC_URI += "file://0033-mpxls1043-added-board-support.patch;name=patch0033"
SRC_URI += "file://0034-mpxls1046-added-board-support.patch;name=patch0034"
SRC_URI += "file://0035-mpxls1088-added-board-support.patch;name=patch0035"
SRC_URI += "file://0036-mpxls1028-added-board-support.patch;name=patch0036"
SRC_URI += "file://0037-comels1046a-added-platform.patch;name=patch0037"
SRC_URI += "file://0038-mpxt1042-added-board-support.patch;name=patch0038"
SRC_URI += "file://0039-mpxlx2160-added-board-support.patch;name=patch0039"
SRC_URI += "file://0040-mpxlx2160-update-board-support.patch;name=patch0040"
SRC_URI += "file://0041-Added-microsys-boards-to-Kconfig-and-DT-Makefile.patch;name=patch0041"
SRC_URI += "file://0042-Fixed-Compilation-error.patch;name=patch0042"
SRC_URI += "file://0043-added-localversion-microsys-3.0.patch;name=patch0043"
SRC_URI += "file://0044-Update-localversion-microsys.patch;name=patch0044"
SRC_URI += "file://0045-pcie_layerscape_rc-added-header-files.patch;name=patch0045"
SRC_URI += "file://0046-mpxls1043-Updated-board-support.patch;name=patch0046"
SRC_URI += "file://0047-include-configs-Enabled-force-ENV-default-feature.patch;name=patch0047"
SRC_URI += "file://0048-board-mpxls10xx-removed-sec_init-function.patch;name=patch0048"
SRC_URI += "file://0049-binman-updated-python-import-paths.patch;name=patch0049"
SRC_URI += "file://0050-mpxls1088-Changed-mc-init-address.patch;name=patch0050"
SRC_URI += "file://0051-mpxlx2160-include-configs-Enabled-force-ENV-default-.patch;name=patch0051"
SRC_URI += "file://0052-localversion-microsys-Update-3.1.patch;name=patch0052"
SRC_URI += "file://0053-pci-update-the-highest-subordinate-bus-number-for-br.patch;name=patch0053"
SRC_URI += "file://0054-mpxls1088-crx05-dpl-fixed-dpmac-setup.patch;name=patch0054"
SRC_URI += "file://0055-localversion-update-to-4.0.patch;name=patch0055"

SRC_URI[patch0001.md5sum] = "72cb61bc8a98bac13ecfe874fe2832e9"
SRC_URI[patch0002.md5sum] = "f48b96078a4318a27dbdddd27a1b74ae"
SRC_URI[patch0003.md5sum] = "b2edaead62b1a4be6f9056462205df49"
SRC_URI[patch0004.md5sum] = "e028d69b2a7b1d901971e46883c6007f"
SRC_URI[patch0005.md5sum] = "37890b6b86e0dc6b3b7ec13dc1f81747"
SRC_URI[patch0006.md5sum] = "44a854ac7db2d052eb4e125cabbc73bf"
SRC_URI[patch0007.md5sum] = "fef24568955c8aac967bd543d31c8c10"
SRC_URI[patch0008.md5sum] = "29e8343a2216853451bf02df3dba61ca"
SRC_URI[patch0009.md5sum] = "b4c059ed35993bbcf19ec9ee0a99daf3"
SRC_URI[patch0010.md5sum] = "666dabbd27e9b8d655d310007297fb93"
SRC_URI[patch0011.md5sum] = "c603c1365a4e342c146fcc84669b7c24"
SRC_URI[patch0012.md5sum] = "6500b414f93856e20866f7c74c36e334"
SRC_URI[patch0013.md5sum] = "5d9d4e8f0c5ae2cc46fa0a9019ff76f0"
SRC_URI[patch0014.md5sum] = "f30c5f3dee6d6a91be6831f204b72cfb"
SRC_URI[patch0015.md5sum] = "b8b0583d0323c7de7a33652f379cdc44"
SRC_URI[patch0016.md5sum] = "3bc77579ee2795b749b4ebacd8bacdf5"
SRC_URI[patch0017.md5sum] = "1b5a12d02cdd73f600752b1d153658a6"
SRC_URI[patch0018.md5sum] = "97beb2eace1123e5010bea5b19dad9e1"
SRC_URI[patch0019.md5sum] = "f9743cfdf671c2a6783fe68a64907f3c"
SRC_URI[patch0020.md5sum] = "6829d39412c7dfb5de633121a340c01f"
SRC_URI[patch0021.md5sum] = "4de12f4eb5722b7f82c9a540346ed637"
SRC_URI[patch0022.md5sum] = "c1a5240cd77242247524484139dac9ee"
SRC_URI[patch0023.md5sum] = "1bad3c841a8f2696185d31f2d1f2f788"
SRC_URI[patch0024.md5sum] = "308b2e5b904207ff03419f45fe35bc20"
SRC_URI[patch0025.md5sum] = "ee85eb1f4d6cd8643c10cb8dbcea94a8"
SRC_URI[patch0026.md5sum] = "3515927da9168c47674070d16b7926a8"
SRC_URI[patch0027.md5sum] = "4eae4eb5cdedf6cec59e97bf95b7caec"
SRC_URI[patch0028.md5sum] = "64c02921e7e15c25b958eebbc9beb894"
SRC_URI[patch0029.md5sum] = "17ea4478df9ef449f194ac69a3047fe5"
SRC_URI[patch0030.md5sum] = "6ce0c6a9e2131512fb47e790f5e8a6e4"
SRC_URI[patch0031.md5sum] = "293a54e1c3b09823182a1101ec15b9ef"
SRC_URI[patch0032.md5sum] = "7c380559744a95650c21435a0e476b30"
SRC_URI[patch0033.md5sum] = "7df97ea427c9dcb55bda81943730c6c9"
SRC_URI[patch0034.md5sum] = "3885d680e14a313590276ee13c257ba8"
SRC_URI[patch0035.md5sum] = "ae1272346952eca5cca61fc0e7273f22"
SRC_URI[patch0036.md5sum] = "42522d62026c01fca4c948ece218e85f"
SRC_URI[patch0037.md5sum] = "24e4588cf6818421bf2e1acc27db4ea8"
SRC_URI[patch0038.md5sum] = "d42815dcc78004dd30f6baf908889ab0"
SRC_URI[patch0039.md5sum] = "e142deaa93c8152e29dede77b5ece4ab"
SRC_URI[patch0040.md5sum] = "b0353313de1e3f5269712ed1c0dbd658"
SRC_URI[patch0041.md5sum] = "ef527ae4bfd93d1b5aa2e366cb4cdc0b"
SRC_URI[patch0042.md5sum] = "be04d249e1886c010e0e0396aca14b08"
SRC_URI[patch0043.md5sum] = "6f71845c26c7051d0769e631754659a8"
SRC_URI[patch0044.md5sum] = "2ad2df5b51b75f026d3b9b6f2b81d8ea"
SRC_URI[patch0045.md5sum] = "b65f3cf9a7d77da892bfc7015e0acd5e"
SRC_URI[patch0046.md5sum] = "882a1e498a49b8f09612e42eda9ed47b"
SRC_URI[patch0047.md5sum] = "1a6f898a69c500674d4a8d44e90974f2"
SRC_URI[patch0048.md5sum] = "dfa4cddc478fdd78ad919ce999a6fff2"
SRC_URI[patch0049.md5sum] = "ec5972bc25660dee0b360b90dd7aa64f"
SRC_URI[patch0050.md5sum] = "0e34cfd4e9a1feab86e4fc7cf7c0d74f"
SRC_URI[patch0051.md5sum] = "2614e2ae46a929ad758fe447004b67de"
SRC_URI[patch0052.md5sum] = "0b59f664117b8266c4de1e30a7f53018"
SRC_URI[patch0053.md5sum] = "deedf539ea1c85d1a3fa948f1d9986da"
SRC_URI[patch0054.md5sum] = "7548a26cf056c851fc8c0ea67b1e47ae"
SRC_URI[patch0055.md5sum] = "0fc24b08bec6ec48309a60d5141b6b08"
